# Welcome to django-finance

[<img src="https://github.com/thomst/django-finance/actions/workflows/ci.yml/badge.svg">](https://github.com/thomst/django-finance/)
[<img src="https://coveralls.io/repos/github/thomst/django-finance/badge.svg?branch=main">](https://coveralls.io/github/thomst/django-finance?branch=main)
[<img src="https://img.shields.io/badge/python-3.8%20%7C%203.9%20%7C%203.10%20%7C%203.11-blue">](https://img.shields.io/badge/python-3.8%20%7C%203.9%20%7C%203.10%20%7C%203.11-blue)
[<img src="https://img.shields.io/badge/django-3.1%20%7C%203.2%20%7C%204.0%20%7C%204.1%20%7C%204.2%20%7C%205.0%20%7C%205.1-orange">](https://img.shields.io/badge/django-3.1%20%7C%203.2%20%7C%204.0%20%7C%204.1%20%7C%204.2%20%7C%205.0%20%7C%205.1-orange)


## Description

**TODO**


## Setup

Install via pip:
```
pip install django-finance
```

Add `finance` to your `INSTALLED_APPS`:
```
INSTALLED_APPS = [
   'finance',
   ...
]
```

## Getting started

Feel free to use the example project. (Actually it is all you need for a fully
functional money split application.)

Start it with:
```
python example/manage.py loaddata example/fixtures/testdata.json
python example/manage.py changepassword admin # Choose your password
python example/manage.py runserver
```
Then check it out by visiting `localhost:8000`.


## Usage

**TODO**